@@ -1,21 +1,7 @@
 /*
-    Copyright 2011 Ilia Kats <ilia-kats@gmx.net>
+    SPDX-FileCopyrightText: 2011 Ilia Kats <ilia-kats@gmx.net>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "secretagent.h"
@@ -24,40 +10,38 @@
 #include "nmdebug.h"
 
 #undef signals
-#include <nm-version.h>
-#if NM_CHECK_VERSION(1, 0, 0)
 #include <libnm/NetworkManager.h>
 #include <NetworkManager.h>
-#endif
+
 #define signals Q_SIGNALS
 
-#include <QDBusArgument>
 #include <QDBusConnection>
 
 #include "agentmanagerinterface.h"
 #include "secretagentadaptor.h"
 
-NetworkManager::SecretAgentPrivate::SecretAgentPrivate(const QString &id, NetworkManager::SecretAgent *parent)
+NetworkManager::SecretAgentPrivate::SecretAgentPrivate(const QString &id, const NetworkManager::SecretAgent::Capabilities capabilities, NetworkManager::SecretAgent *parent)
     : q_ptr(parent)
     , agent(parent)
 #ifdef NMQT_STATIC
     , agentManager(NetworkManagerPrivate::DBUS_SERVICE, QLatin1String(NM_DBUS_PATH_AGENT_MANAGER), QDBusConnection::sessionBus(), parent)
-    , watcher(NetworkManagerPrivate::DBUS_SERVICE, QDBusConnection::sessionBus(), QDBusServiceWatcher::WatchForRegistration, parent)
 #else
     , agentManager(NetworkManagerPrivate::DBUS_SERVICE, QLatin1String(NM_DBUS_PATH_AGENT_MANAGER), QDBusConnection::systemBus(), parent)
-    , watcher(NetworkManagerPrivate::DBUS_SERVICE, QDBusConnection::systemBus(), QDBusServiceWatcher::WatchForRegistration, parent)
 #endif
     , agentId(id)
+    , capabilities(capabilities)
 {
     Q_Q(SecretAgent);
 
     qRegisterMetaType<NMVariantMapMap>("NMVariantMapMap");
     qDBusRegisterMetaType<NMVariantMapMap>();
 
-    watcher.connect(&watcher, SIGNAL(serviceRegistered(QString)), q, SLOT(registerAgent()));
+    agentManager.connection().connect(NetworkManagerPrivate::DBUS_SERVICE, "/org/freedesktop", NetworkManagerPrivate::FDO_DBUS_OBJECT_MANAGER,
+                               QLatin1String("InterfacesAdded"), q, SLOT(dbusInterfacesAdded(QDBusObjectPath,QVariantMap)));
+
     agentManager.connection().registerObject(QLatin1String(NM_DBUS_PATH_SECRET_AGENT), &agent, QDBusConnection::ExportAllSlots);
 
-    registerAgent();
+    registerAgent(capabilities);
 }
 
 NetworkManager::SecretAgentPrivate::~SecretAgentPrivate()
@@ -65,15 +49,36 @@ NetworkManager::SecretAgentPrivate::~SecretAgentPrivate()
     agentManager.Unregister();
 }
 
+void NetworkManager::SecretAgentPrivate::dbusInterfacesAdded(const QDBusObjectPath &path, const QVariantMap &interfaces)
+{
+	Q_UNUSED(path);
+	if(!interfaces.contains(QString::fromLatin1(agentManager.staticInterfaceName())))
+		return;
+
+	registerAgent(capabilities);
+}
+
 void NetworkManager::SecretAgentPrivate::registerAgent()
 {
-    agentManager.Register(agentId);
+    agentManager.RegisterWithCapabilities(agentId, NetworkManager::SecretAgent::Capability::NoCapability);
+}
+
+void NetworkManager::SecretAgentPrivate::registerAgent(NetworkManager::SecretAgent::Capabilities capabilities)
+{
+    agentManager.RegisterWithCapabilities(agentId, capabilities);
 }
 
 NetworkManager::SecretAgent::SecretAgent(const QString &id, QObject *parent)
     : QObject(parent)
     , QDBusContext()
-    , d_ptr(new NetworkManager::SecretAgentPrivate(id, this))
+    , d_ptr(new NetworkManager::SecretAgentPrivate(id, NetworkManager::SecretAgent::Capability::NoCapability, this))
+{
+}
+
+NetworkManager::SecretAgent::SecretAgent(const QString &id, NetworkManager::SecretAgent::Capabilities capabilities, QObject *parent)
+    : QObject(parent)
+    , QDBusContext()
+    , d_ptr(new NetworkManager::SecretAgentPrivate(id, capabilities, this))
 {
 }
 
