@@ -1,22 +1,8 @@
 /*
-    Copyright 2012-2013  Jan Grulich <jgrulich@redhat.com>
-    Copyright 2013 Daniel Nicoletti <dantti12@gmail.com>
+    SPDX-FileCopyrightText: 2012-2013 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2013 Daniel Nicoletti <dantti12@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "connectionsettings.h"
@@ -48,7 +34,6 @@
 #include "wireguardsetting.h"
 
 #undef signals
-#include <libnm/NetworkManager.h>
 
 #if !NM_CHECK_VERSION(1, 6, 0)
 #define NM_SETTING_CONNECTION_AUTOCONNECT_RETRIES "autoconnect-retries"
@@ -523,8 +508,8 @@ void NetworkManager::ConnectionSettings::fromMap(const NMVariantMapMap &map)
         setInterfaceName(connectionSettings.value(QLatin1String(NM_SETTING_CONNECTION_INTERFACE_NAME)).toString());
     }
     if (connectionSettings.contains(QLatin1String(NM_SETTING_CONNECTION_PERMISSIONS))) {
-        QStringList permissions = connectionSettings.value(QLatin1String(NM_SETTING_CONNECTION_PERMISSIONS)).toStringList();
-        Q_FOREACH (const QString & permission, permissions) {
+        const QStringList permissions = connectionSettings.value(QLatin1String(NM_SETTING_CONNECTION_PERMISSIONS)).toStringList();
+        for (const QString & permission : permissions) {
 #if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
             const QStringList split = permission.split(QLatin1Char(':'), QString::KeepEmptyParts);
 #else
@@ -591,7 +576,8 @@ void NetworkManager::ConnectionSettings::fromMap(const NMVariantMapMap &map)
         setStableId(connectionSettings.value(QLatin1String(NM_SETTING_CONNECTION_STABLE_ID)).toString());
     }
 
-    Q_FOREACH (const Setting::Ptr & setting, settings()) {
+    const auto settingsList = settings();
+    for (const Setting::Ptr &setting : settingsList) {
         if (map.contains(setting->name())) {
             setting->fromMap(map.value(setting->name()));
             setting->setInitialized(true);
@@ -685,7 +671,8 @@ NMVariantMapMap NetworkManager::ConnectionSettings::toMap() const
 
     result.insert(QLatin1String(NM_SETTING_CONNECTION_SETTING_NAME), connectionSetting);
 
-    Q_FOREACH (const Setting::Ptr & setting, settings()) {
+    const auto settingsList = settings();
+    for (const Setting::Ptr &setting : settingsList) {
         QVariantMap map = setting->toMap();
         if (!setting->isNull()) {
             result.insert(setting->name(), map);
@@ -984,7 +971,8 @@ void NetworkManager::ConnectionSettings::setStableId(const QString &stableId)
 
 NetworkManager::Setting::Ptr NetworkManager::ConnectionSettings::setting(Setting::SettingType type) const
 {
-    Q_FOREACH (const Setting::Ptr & setting, settings()) {
+    const auto settingsList = settings();
+    for (const Setting::Ptr &setting : settingsList) {
         if (setting->type() == type) {
             return setting;
         }
@@ -1030,7 +1018,8 @@ QDebug NetworkManager::operator <<(QDebug dbg, const NetworkManager::ConnectionS
     dbg.nospace() << NM_SETTING_CONNECTION_METERED << ": " << setting.metered() << '\n';
     dbg.nospace() << NM_SETTING_CONNECTION_STABLE_ID << ": " << setting.stableId() << '\n';
     dbg.nospace() << "===================\n";
-    Q_FOREACH (const Setting::Ptr & settingPtr, setting.settings()) {
+    const auto settingsList = setting.settings();
+    for (const Setting::Ptr &settingPtr : settingsList) {
         dbg.nospace() << settingPtr->typeAsString(settingPtr->type()).toUpper() << " SETTINGS\n";
         dbg.nospace() << "---------------------------\n";
         switch (settingPtr->type()) {
