@@ -1,21 +1,7 @@
 /*
-    Copyright 2012-2013  Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2012-2013 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef NETWORKMANAGERQT_IPV4_SETTING_H
@@ -25,7 +11,7 @@
 #include <networkmanagerqt/networkmanagerqt_export.h>
 #include "setting.h"
 
-#include <QtCore/QStringList>
+#include <QStringList>
 #include <QtNetwork/QHostAddress>
 
 #define NMQT_SETTING_IP4_CONFIG_SETTING_NAME       NM_SETTING_IP4_CONFIG_SETTING_NAME
@@ -48,6 +34,13 @@
 #define NMQT_SETTING_IP4_CONFIG_METHOD_MANUAL      NM_SETTING_IP4_CONFIG_METHOD_MANUAL
 #define NMQT_SETTING_IP4_CONFIG_METHOD_SHARED      NM_SETTING_IP4_CONFIG_METHOD_SHARED
 #define NMQT_SETTING_IP4_CONFIG_METHOD_DISABLED    NM_SETTING_IP4_CONFIG_METHOD_DISABLED
+#define NMQT_SETTING_IP4_CONFIG_DAD_TIMEOUT        NM_SETTING_IP_CONFIG_DAD_TIMEOUT
+#define NMQT_SETTING_IP4_CONFIG_DHCP_FQDN          NM_SETTING_IP4_CONFIG_DHCP_FQDN
+#define NMQT_SETTING_IP4_CONFIG_DNS_OPTIONS        NM_SETTING_IP_CONFIG_DNS_OPTIONS
+#define NMQT_SETTING_IP4_CONFIG_DNS_PRIORITY       NM_SETTING_IP_CONFIG_DNS_PRIORITY
+#define NMQT_SETTING_IP4_CONFIG_GATEWAY            NM_SETTING_IP_CONFIG_GATEWAY
+#define NMQT_SETTING_IP4_CONFIG_ROUTE_DATA         "route-data"
+#define NMQT_SETTING_IP4_CONFIG_ADDRESS_DATA       "address-data"
 
 
 namespace NetworkManager
@@ -110,6 +103,27 @@ public:
     void setMayFail(bool mayFail);
     bool mayFail() const;
 
+    void setDadTimeout(qint32 timeout);
+    qint32 dadTimeout() const;
+
+    void setDhcpFqdn(const QString &fqdn);
+    QString dhcpFqdn() const;
+
+    void setDnsOptions(const QStringList &options);
+    QStringList dnsOptions() const;
+
+    void setDnsPriority(qint32 priority);
+    qint32 dnsPriority() const;
+
+    void setGateway(const QString &gateway);
+    QString gateway() const;
+
+    void setAddressData(const NMVariantMapList &addressData);
+    NMVariantMapList addressData() const;
+
+    void setRouteData(const NMVariantMapList &routeData);
+    NMVariantMapList routeData() const;
+
     void fromMap(const QVariantMap &setting) override;
 
     QVariantMap toMap() const override;
