@@ -1,21 +1,7 @@
 /*
-    Copyright 2012-2013  Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2012-2013 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "wirelesssecuritysetting.h"
@@ -40,7 +26,7 @@ NetworkManager::WirelessSecuritySetting::WirelessSecuritySetting()
 { }
 
 NetworkManager::WirelessSecuritySetting::WirelessSecuritySetting(const Ptr &other)
-    : Setting(Setting::WirelessSecurity)
+    : Setting(other)
     , d_ptr(new WirelessSecuritySettingPrivate())
 {
     setKeyMgmt(other->keyMgmt());
@@ -405,7 +391,7 @@ QStringList NetworkManager::WirelessSecuritySetting::needSecrets(bool requestNew
     }
 
     if (keyMgmt() == WpaNone ||
-            keyMgmt() == WpaPsk) {
+            keyMgmt() == WpaPsk || keyMgmt() == SAE) {
         if (!pskFlags().testFlag(Setting::NotRequired)) {
             if (psk().isEmpty() || requestNew) {
                 secrets << QLatin1String(NM_SETTING_WIRELESS_SECURITY_PSK);
@@ -442,7 +428,7 @@ void NetworkManager::WirelessSecuritySetting::fromMap(const QVariantMap &map)
         } else if (key == "wpa-eap") {
             setKeyMgmt(WpaEap);
         } else if (key == "sae") {
-            setKeyMgmt(WpaSae);
+            setKeyMgmt(SAE);
         }
     }
 
@@ -464,7 +450,7 @@ void NetworkManager::WirelessSecuritySetting::fromMap(const QVariantMap &map)
     if (map.contains(QLatin1String(NM_SETTING_WIRELESS_SECURITY_PROTO))) {
         const QStringList strList = map.value(QLatin1String(NM_SETTING_WIRELESS_SECURITY_PROTO)).toStringList();
         QList<WpaProtocolVersion> list;
-        Q_FOREACH (const QString & str, strList) {
+        for (const QString &str : strList) {
             if (str == "wpa") {
                 list.push_back(Wpa);
             } else if (str == "rsn") {
@@ -477,7 +463,7 @@ void NetworkManager::WirelessSecuritySetting::fromMap(const QVariantMap &map)
     if (map.contains(QLatin1String(NM_SETTING_WIRELESS_SECURITY_PAIRWISE))) {
         const QStringList strList = map.value(QLatin1String(NM_SETTING_WIRELESS_SECURITY_PAIRWISE)).toStringList();
         QList<WpaEncryptionCapabilities> list;
-        Q_FOREACH (const QString & str, strList) {
+        for (const QString &str : strList) {
             if (str == "wep40") {
                 list.push_back(Wep40);
             } else if (str == "wep104") {
@@ -494,7 +480,7 @@ void NetworkManager::WirelessSecuritySetting::fromMap(const QVariantMap &map)
     if (map.contains(QLatin1String(NM_SETTING_WIRELESS_SECURITY_GROUP))) {
         const QStringList strList = map.value(QLatin1String(NM_SETTING_WIRELESS_SECURITY_GROUP)).toStringList();
         QList<WpaEncryptionCapabilities> list;
-        Q_FOREACH (const QString & str, strList) {
+        for (const QString &str : strList) {
             if (str == "wep40") {
                 list.push_back(Wep40);
             } else if (str == "wep104") {
@@ -573,7 +559,7 @@ QVariantMap NetworkManager::WirelessSecuritySetting::toMap() const
         setting.insert(QLatin1String(NM_SETTING_WIRELESS_SECURITY_KEY_MGMT), "wpa-psk");
     } else if (keyMgmt() == WpaEap) {
         setting.insert(QLatin1String(NM_SETTING_WIRELESS_SECURITY_KEY_MGMT), "wpa-eap");
-    } else if (keyMgmt() == WpaSae) {
+    } else if (keyMgmt() == SAE) {
         setting.insert(QLatin1String(NM_SETTING_WIRELESS_SECURITY_KEY_MGMT), "sae");
     }
 
@@ -593,7 +579,8 @@ QVariantMap NetworkManager::WirelessSecuritySetting::toMap() const
 
     if (!proto().isEmpty()) {
         QStringList strList;
-        Q_FOREACH (const WpaProtocolVersion & version, proto()) {
+        const auto protoList = proto();
+        for (const WpaProtocolVersion &version : protoList) {
             if (version == Wpa) {
                 strList << "wpa";
             } else if (version == Rsn) {
@@ -605,7 +592,8 @@ QVariantMap NetworkManager::WirelessSecuritySetting::toMap() const
 
     if (!pairwise().isEmpty()) {
         QStringList strList;
-        Q_FOREACH (const WpaEncryptionCapabilities & capability, pairwise()) {
+        const auto encryptions = pairwise();
+        for (const WpaEncryptionCapabilities &capability : encryptions) {
             if (capability == Wep40) {
                 strList << "wep40";
             } else if (capability == Wep104) {
@@ -621,7 +609,8 @@ QVariantMap NetworkManager::WirelessSecuritySetting::toMap() const
 
     if (!group().isEmpty()) {
         QStringList strList;
-        Q_FOREACH (const WpaEncryptionCapabilities & capability, group()) {
+        const auto encryptions = group();
+        for (const WpaEncryptionCapabilities &capability : encryptions) {
             if (capability == Wep40) {
                 strList << "wep40";
             } else if (capability == Wep104) {
